==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/BaseSchemaRequestElement.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour BaseSchemaRequestElement complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="BaseSchemaRequestElement">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ESIGNATURE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BaseSchemaRequestElement", propOrder = {
    "esignature"
})
public class BaseSchemaRequestElement {

    @XmlElement(name = "ESIGNATURE")
    protected ESIGNATURE esignature;

    /**
     * Obtient la valeur de la propriété esignature.
     * 
     * @return
     *     possible object is
     *     {@link ESIGNATURE }
     *     
     */
    public ESIGNATURE getESIGNATURE() {
        return esignature;
    }

    /**
     * Définit la valeur de la propriété esignature.
     * 
     * @param value
     *     allowed object is
     *     {@link ESIGNATURE }
     *     
     */
    public void setESIGNATURE(ESIGNATURE value) {
        this.esignature = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/BaseSchemaRequestElement.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BaseSchemaRequestElement complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BaseSchemaRequestElement">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ESIGNATURE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BaseSchemaRequestElement", propOrder = {
    "esignature"
})
public class BaseSchemaRequestElement {

    @XmlElement(name = "ESIGNATURE")
    protected ESIGNATURE esignature;

    /**
     * Gets the value of the esignature property.
     * 
     * @return
     *     possible object is
     *     {@link ESIGNATURE }
     *     
     */
    public ESIGNATURE getESIGNATURE() {
        return esignature;
    }

    /**
     * Sets the value of the esignature property.
     * 
     * @param value
     *     allowed object is
     *     {@link ESIGNATURE }
     *     
     */
    public void setESIGNATURE(ESIGNATURE value) {
        this.esignature = value;
    }

}
